.. currentmodule:: sardana.pool.poolonedexpchannel

:mod:`~sardana.pool.poolonedexpchannel`
=========================================

.. automodule:: sardana.pool.poolonedexpchannel

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`Pool1DExpChannel`


Pool1DExpChannel
-------------------

.. inheritance-diagram:: Pool1DExpChannel
    :parts: 1
    
.. autoclass:: Pool1DExpChannel
    :show-inheritance:
    :members:
    :undoc-members:

